wallaroo.wallaroo_ml_ops_api_client.models.v1_model_get_config_response_200_model_config_tensor_fields API documentation

# wallaroo.wallaroo_ml_ops_api_client.models.v1_model_get_config_response_200_model_config_tensor_fields

View Source

     1from typing import Any, Dict, List, Type, TypeVar
     2
     3import attr
     4
     5T = TypeVar("T", bound="V1ModelGetConfigResponse200ModelConfigTensorFields")
     6
     7@attr.s(auto_attribs=True)
     8class V1ModelGetConfigResponse200ModelConfigTensorFields:
     9    """ Optional Tensor Fields for the model.
    10
    11    """
    12
    13    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    14
    15
    16    def to_dict(self) -> Dict[str, Any]:
    17
    18        field_dict: Dict[str, Any] = {}
    19        field_dict.update(self.additional_properties)
    20        field_dict.update({
    21        })
    22
    23        return field_dict
    24
    25
    26
    27    @classmethod
    28    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    29        d = src_dict.copy()
    30        v1_model_get_config_response_200_model_config_tensor_fields = cls(
    31        )
    32
    33        v1_model_get_config_response_200_model_config_tensor_fields.additional_properties = d
    34        return v1_model_get_config_response_200_model_config_tensor_fields
    35
    36    @property
    37    def additional_keys(self) -> List[str]:
    38        return list(self.additional_properties.keys())
    39
    40    def __getitem__(self, key: str) -> Any:
    41        return self.additional_properties[key]
    42
    43    def __setitem__(self, key: str, value: Any) -> None:
    44        self.additional_properties[key] = value
    45
    46    def __delitem__(self, key: str) -> None:
    47        del self.additional_properties[key]
    48
    49    def __contains__(self, key: str) -> bool:
    50        return key in self.additional_properties

@attr.s(auto_attribs=True)
class V1ModelGetConfigResponse200ModelConfigTensorFields: View Source

     8@attr.s(auto_attribs=True)
     9class V1ModelGetConfigResponse200ModelConfigTensorFields:
    10    """ Optional Tensor Fields for the model.
    11
    12    """
    13
    14    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
    15
    16
    17    def to_dict(self) -> Dict[str, Any]:
    18
    19        field_dict: Dict[str, Any] = {}
    20        field_dict.update(self.additional_properties)
    21        field_dict.update({
    22        })
    23
    24        return field_dict
    25
    26
    27
    28    @classmethod
    29    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    30        d = src_dict.copy()
    31        v1_model_get_config_response_200_model_config_tensor_fields = cls(
    32        )
    33
    34        v1_model_get_config_response_200_model_config_tensor_fields.additional_properties = d
    35        return v1_model_get_config_response_200_model_config_tensor_fields
    36
    37    @property
    38    def additional_keys(self) -> List[str]:
    39        return list(self.additional_properties.keys())
    40
    41    def __getitem__(self, key: str) -> Any:
    42        return self.additional_properties[key]
    43
    44    def __setitem__(self, key: str, value: Any) -> None:
    45        self.additional_properties[key] = value
    46
    47    def __delitem__(self, key: str) -> None:
    48        del self.additional_properties[key]
    49
    50    def __contains__(self, key: str) -> bool:
    51        return key in self.additional_properties

Optional Tensor Fields for the model.

V1ModelGetConfigResponse200ModelConfigTensorFields() View Source

    2def __init__(self, ):
    3    self.additional_properties = __attr_factory_additional_properties()

Method generated by attrs for class V1ModelGetConfigResponse200ModelConfigTensorFields.

def to_dict(self) -> Dict[str, Any]: View Source

    17    def to_dict(self) -> Dict[str, Any]:
    18
    19        field_dict: Dict[str, Any] = {}
    20        field_dict.update(self.additional_properties)
    21        field_dict.update({
    22        })
    23
    24        return field_dict

@classmethod
def from_dict(cls: Type[~T], src_dict: Dict[str, Any]) -> ~T: View Source

    28    @classmethod
    29    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
    30        d = src_dict.copy()
    31        v1_model_get_config_response_200_model_config_tensor_fields = cls(
    32        )
    33
    34        v1_model_get_config_response_200_model_config_tensor_fields.additional_properties = d
    35        return v1_model_get_config_response_200_model_config_tensor_fields

additional_keys: List[str]